@@ -12,8 +12,10 @@ Usage::
         DescribeTapesPaginator,
         DescribeVTLDevicesPaginator,
         ListFileSharesPaginator,
+        ListFileSystemAssociationsPaginator,
         ListGatewaysPaginator,
         ListTagsForResourcePaginator,
+        ListTapePoolsPaginator,
         ListTapesPaginator,
         ListVolumesPaginator,
         StorageGatewayClient,
@@ -29,8 +31,10 @@ Usage::
     describe_tapes_paginator: DescribeTapesPaginator = client.get_paginator("describe_tapes")
     describe_vtl_devices_paginator: DescribeVTLDevicesPaginator = client.get_paginator("describe_vtl_devices")
     list_file_shares_paginator: ListFileSharesPaginator = client.get_paginator("list_file_shares")
+    list_file_system_associations_paginator: ListFileSystemAssociationsPaginator = client.get_paginator("list_file_system_associations")
     list_gateways_paginator: ListGatewaysPaginator = client.get_paginator("list_gateways")
     list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
+    list_tape_pools_paginator: ListTapePoolsPaginator = client.get_paginator("list_tape_pools")
     list_tapes_paginator: ListTapesPaginator = client.get_paginator("list_tapes")
     list_volumes_paginator: ListVolumesPaginator = client.get_paginator("list_volumes")
     ```
@@ -42,8 +46,10 @@ from mypy_boto3_storagegateway.paginator import (
     DescribeTapesPaginator,
     DescribeVTLDevicesPaginator,
     ListFileSharesPaginator,
+    ListFileSystemAssociationsPaginator,
     ListGatewaysPaginator,
     ListTagsForResourcePaginator,
+    ListTapePoolsPaginator,
     ListTapesPaginator,
     ListVolumesPaginator,
 )
@@ -58,8 +64,10 @@ __all__ = (
     "DescribeTapesPaginator",
     "DescribeVTLDevicesPaginator",
     "ListFileSharesPaginator",
+    "ListFileSystemAssociationsPaginator",
     "ListGatewaysPaginator",
     "ListTagsForResourcePaginator",
+    "ListTapePoolsPaginator",
     "ListTapesPaginator",
     "ListVolumesPaginator",
     "StorageGatewayClient",
